@@ -2,9 +2,8 @@ package Test::UseAllModules;
 
 use strict;
 use warnings;
-use ExtUtils::Manifest qw( maniread );
 
-our $VERSION = '0.09_01';
+our $VERSION = '0.04';
 
 use Exporter;
 
@@ -19,16 +18,10 @@ sub all_uses_ok {
   my @exceptions = @_;
   my @modules;
 
-  unless (-f 'MANIFEST') {
-    plan skip_all => 'no MANIFEST';
-    exit;
-  }
-
-  my $manifest = maniread();
-
+  open my $fh, '<', 'MANIFEST';
 READ:
-  foreach my $file (keys %{ $manifest }) {
-    if (my ($module) = $file =~ m|^lib/(.*)\.pm\s*$|) {
+  while(my $file = <$fh>) {
+    if (my ($module) = $file =~ m|^lib/(.*)\.pm$|) {
       $module =~ s|/|::|g;
 
       foreach my $rule (@exceptions) {
@@ -38,11 +31,8 @@ READ:
       push @modules, $module;
     }
   }
+  close $fh;
 
-  unless (@modules) {
-    plan skip_all => 'no .pm files are found under the lib directory';
-    exit;
-  }
   plan tests => scalar @modules;
 
   my @failed;
@@ -58,7 +48,7 @@ __END__
 
 =head1 NAME
 
-Test::UseAllModules - do use_ok() for all the MANIFESTed modules
+Test::UseAllModules - do use_ok() for all modules MANIFESTed
 
 =head1 SYNOPSIS
 
@@ -94,9 +84,9 @@ modify the test any more (hopefully).
 =head2 all_uses_ok
 
 Does Test::More's use_ok() for every module found in MANIFEST.
-Tests only modules under the 'lib' directory. If you have modules
-you don't want to test, give those modules or some regex rules
-as the argument. The word 'except' will be ignored as shown
+Tests only modules under 'lib/' directory. If you have modules
+you don't want to test, give the module name(s) or regex rule
+for the argument. The word 'except' will be ignored as shown
 above.
 
 =head1 NOTES
